using BinaryProvider # requires BinaryProvider 0.3.0 or later

# Parse some basic command-line arguments
const verbose = "--verbose" in ARGS
const prefix = Prefix(get([a for a in ARGS if a != "--verbose"], 1, joinpath(@__DIR__, "usr")))
products = [
    LibraryProduct(prefix, String["libvorbis"], :libvorbis),
]

# Download binaries from hosted location
bin_prefix = "https://github.com/JuliaIO/LibVorbisBuilder/releases/download/v1.3.6"

# Listing of files generated by BinaryBuilder:
download_info = Dict(
    Linux(:aarch64, :glibc) => ("$bin_prefix/libvorbis.v1.3.6.aarch64-linux-gnu.tar.gz", "e8a419c64f1a42383a8944646c9ef84422dd6b5887051b7fc8921785c8bec546"),
    Linux(:armv7l, :glibc, :eabihf) => ("$bin_prefix/libvorbis.v1.3.6.arm-linux-gnueabihf.tar.gz", "a0453c751f47ebf696bebc2440f58aef14451d27e7ff8886a7e418492a9744f9"),
    Linux(:i686, :glibc) => ("$bin_prefix/libvorbis.v1.3.6.i686-linux-gnu.tar.gz", "875ecb80c52d00b921ac19c792c5635c3d729f3a0e26e3256a5457150a6f40c5"),
    Linux(:i686, :musl) => ("$bin_prefix/libvorbis.v1.3.6.i686-linux-musl.tar.gz", "a2942a7d52a67633243614103d12f6f11b54dd43f77c4628489cee9f76106467"),
    Windows(:i686) => ("$bin_prefix/libvorbis.v1.3.6.i686-w64-mingw32.tar.gz", "de309af9ca79d7b58296a9303ac7928b170da4e0df6ff44b1b5aada7348765bc"),
    Linux(:powerpc64le, :glibc) => ("$bin_prefix/libvorbis.v1.3.6.powerpc64le-linux-gnu.tar.gz", "dfb17ebfe7616a22b629ad9cc5dd61b8c839c4190e84f2c872000ee36cb9d242"),
    MacOS(:x86_64) => ("$bin_prefix/libvorbis.v1.3.6.x86_64-apple-darwin14.tar.gz", "c94d194d0eb4d21b8ee448279d396adeaf5906e76edcc9ef61e10ff9d6523dd8"),
    Linux(:x86_64, :glibc) => ("$bin_prefix/libvorbis.v1.3.6.x86_64-linux-gnu.tar.gz", "fb4f1730c2fb45214c606935ea83f56a049c9ca11cec539af51c5741fe506d4b"),
    Linux(:x86_64, :musl) => ("$bin_prefix/libvorbis.v1.3.6.x86_64-linux-musl.tar.gz", "54689eaff5167da1d9d68e433be213a9094005e7f6a675f0378004d31a80ba15"),
    FreeBSD(:x86_64) => ("$bin_prefix/libvorbis.v1.3.6.x86_64-unknown-freebsd11.1.tar.gz", "d19c7102c47ecf0ebd773bd56bc874651874607f927f58c14ac7712a2ac12c0a"),
    Windows(:x86_64) => ("$bin_prefix/libvorbis.v1.3.6.x86_64-w64-mingw32.tar.gz", "669f771b02fe1b255e9522f862d07921126cf8ca7939f7220ec9d0d6d3ed7cc5"),
)

# Install unsatisfied or updated dependencies:
unsatisfied = any(!satisfied(p; verbose=verbose) for p in products)
if haskey(download_info, platform_key())
    url, tarball_hash = download_info[platform_key()]
    if unsatisfied || !isinstalled(url, tarball_hash; prefix=prefix)
        # Download and install binaries
        install(url, tarball_hash; prefix=prefix, force=true, verbose=verbose)
    end
elseif unsatisfied
    # If we don't have a BinaryProvider-compatible .tar.gz to download, complain.
    # Alternatively, you could attempt to install from a separate provider,
    # build from source or something even more ambitious here.
    error("Your platform $(triplet(platform_key())) is not supported by this package!")
end

# Write out a deps.jl file that will contain mappings for our products
write_deps_file(joinpath(@__DIR__, "deps_codec.jl"), products)
